#
Benchopt results: sSVM

Last updated: 2023-10-10 20:52 with 1 result files in total.

Results | Datasets | System info |
--- | --- | --- | ---
sSVM 2023-10-10 20h52m22 | Classification_data dataset_name=steel-plates-fault dataset_name=philippine dataset_name=sylva_prior dataset_name=creditcard | CPU: 4 RAM (GB): 31 CUDA: NVIDIA GeForce RTX 4090: cuda_12.2 platform: Linux6.2.0-34-generic-x86_64 processor: 13th Gen Intel(R) Core(TM) i9-13900K |

dialog text